Status and History
==================

Ldaptor was created by `Tommi Virtanen <https://github.com/tv42>`_ who developed it during the years 2001-2008.
From 2007 and onwards mainly bug fixes were added, many contributed by Debian maintainers.
Development picked back up in 2014 by `Bret Curtis <https://github.com/psi29a>`_ with Tommi's consent and was migrated to Twisted where it is a first-party Twisted library.
Ldaptor can be found here:

`<https://github.com/twisted/ldaptor>`_

The LDAP client library functionality is in active use.
It is stable and works very well.
